@@ -46,7 +46,7 @@ CgmmParametersEstim_CTS <- function(x, algo = c("2SCgmm", "ITCgmm", "CueCgmm"),
                                           ...)
     }, stop(paste(algo, " not taken into account for Cgmm procedure")))
     if (PrintTime) {
-        CallingFct <- paste("Classic", "CgmmParametersEstim", algo, sep = "_")
+        CallingFct <- paste("CTS", "CgmmParametersEstim", algo, sep = "_")
         StableEstim::PrintDuration(
           StableEstim::ComputeDuration(t_init, StableEstim::getTime_()),
           CallingFct)
