@@ -45,7 +45,7 @@ CgmmParametersEstim_TSS <- function(x, algo = c("2SCgmm", "ITCgmm", "CueCgmm"),
                                           ...)
     }, stop(paste(algo, " not taken into account for Cgmm procedure")))
     if (PrintTime) {
-        CallingFct <- paste("Subordinator", "CgmmParametersEstim", algo,
+        CallingFct <- paste("TSS", "CgmmParametersEstim", algo,
                             sep = "_")
         StableEstim::PrintDuration(
           StableEstim::ComputeDuration(t_init, StableEstim::getTime_()),
