@@ -75,7 +75,7 @@ GMMParametersEstim_NTS <-
                     stop(paste(algo, " not taken into account !")))
     if (PrintTime) {
       CallingFct <-
-        paste("Normal", "GMMParametersEstim", algo, t_scheme, sep = "_")
+        paste("NTS", "GMMParametersEstim", algo, t_scheme, sep = "_")
       StableEstim::PrintDuration(
         StableEstim::ComputeDuration(t_init, StableEstim::getTime_()),
         CallingFct)
