@@ -1,12 +1,12 @@
 
-### Classic ###
+### CTS ###
 
 
-test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_cutoff", {
+test_that("TemperedEstim_Simulation_with_CTS_GMM_CueGMM_cutoff", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.5,1,1,1,1,0)),
-    SampleSizes = 4, MCparam = 1, TemperedType = "Classic",
+    SampleSizes = 4, MCparam = 1, TemperedType = "CTS",
     Estimfct = "GMM", saveOutput = FALSE, algo = "CueGMM",
     regularization = "cut-off", WeightingMatrix = "OptAsym",
     t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
@@ -23,11 +23,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_cutoff", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_Tikhonov", {
+test_that("TemperedEstim_Simulation_with_CTS_GMM_CueGMM_Tikhonov", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.5,1,1,1,1,0)),
-    SampleSizes = 4, MCparam = 1, TemperedType = "Classic",
+    SampleSizes = 4, MCparam = 1, TemperedType = "CTS",
     Estimfct = "GMM", saveOutput = FALSE, algo = "CueGMM",
     regularization = "Tikhonov", WeightingMatrix = "OptAsym",
     t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
@@ -45,11 +45,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_Tikhonov", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_LF", {
+test_that("TemperedEstim_Simulation_with_CTS_GMM_CueGMM_LF", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.5,1,1,1,1,0)),
-    SampleSizes = 4, MCparam = 1, TemperedType = "Classic",
+    SampleSizes = 4, MCparam = 1, TemperedType = "CTS",
     Estimfct = "GMM", saveOutput = FALSE, algo = "CueGMM",
     regularization = "LF", WeightingMatrix = "OptAsym",
     t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
@@ -67,11 +67,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_LF", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMM_ITGMM_cutoff", {
+test_that("TemperedEstim_Simulation_with_CTS_GMM_ITGMM_cutoff", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.5,1,1,1,1,0)),
-    SampleSizes = 4, MCparam = 1, TemperedType = "Classic",
+    SampleSizes = 4, MCparam = 1, TemperedType = "CTS",
     Estimfct = "GMM", saveOutput = FALSE, algo = "ITGMM",
     regularization = "cut-off", WeightingMatrix = "OptAsym",
     t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
@@ -89,11 +89,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMM_ITGMM_cutoff", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_cutoff_IC", {
+test_that("TemperedEstim_Simulation_with_CTS_GMM_CueGMM_cutoff_IC", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.5,1,1,1,1,0)),
-    SampleSizes = 4, MCparam = 1, TemperedType = "Classic",
+    SampleSizes = 4, MCparam = 1, TemperedType = "CTS",
     Estimfct = "GMM", saveOutput = FALSE, algo = "CueGMM",
     regularization = "cut-off", WeightingMatrix = "OptAsym",
     t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12),
@@ -113,11 +113,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMM_CueGMM_cutoff_IC", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_Cgmm_CueCgmm", {
+test_that("TemperedEstim_Simulation_with_CTS_Cgmm_CueCgmm", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.45,0.55,1,1,1,0)), SampleSizes = 4,
-    MCparam = 1, TemperedType = "Classic", Estimfct = "Cgmm",
+    MCparam = 1, TemperedType = "CTS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "CueCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -135,11 +135,11 @@ test_that("TemperedEstim_Simulation_with_Classic_Cgmm_CueCgmm", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_Cgmm_ITCgmm", {
+test_that("TemperedEstim_Simulation_with_CTS_Cgmm_ITCgmm", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.45,0.55,1,1,1,0)), SampleSizes = 2,
-    MCparam = 2, TemperedType = "Classic", Estimfct = "Cgmm",
+    MCparam = 2, TemperedType = "CTS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "ITCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -157,11 +157,11 @@ test_that("TemperedEstim_Simulation_with_Classic_Cgmm_ITCgmm", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Normal_Cgmm_ITCgmm", {
+test_that("TemperedEstim_Simulation_with_NTS_Cgmm_ITCgmm", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(0.5,1,1,1,0)), SampleSizes = 4,
-    MCparam = 1, TemperedType = "Normal", Estimfct = "Cgmm",
+    MCparam = 1, TemperedType = "NTS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "ITCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -177,11 +177,11 @@ test_that("TemperedEstim_Simulation_with_Normal_Cgmm_ITCgmm", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Normal_Cgmm_CueCgmm", {
+test_that("TemperedEstim_Simulation_with_NTS_Cgmm_CueCgmm", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(0.5,1,1,1,0)), SampleSizes = 4,
-    MCparam = 1, TemperedType = "Normal", Estimfct = "Cgmm",
+    MCparam = 1, TemperedType = "NTS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "CueCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -198,11 +198,11 @@ test_that("TemperedEstim_Simulation_with_Normal_Cgmm_CueCgmm", {
 })
 
 
-test_that("TemperedEstim_Simulation_with_Classic_GMC_IT", {
+test_that("TemperedEstim_Simulation_with_CTS_GMC_IT", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(1.45,0.55,1,1,1,0)), SampleSizes = 4,
-    MCparam = 1, TemperedType = "Classic", Estimfct = "GMC",
+    MCparam = 1, TemperedType = "CTS", Estimfct = "GMC",
     saveOutput = FALSE, algo = "ITGMC", alphaReg = 0.01,
     WeightingMatrix = "OptAsym", regularization = "cut-off", ncond = 8)
 
@@ -219,14 +219,14 @@ test_that("TemperedEstim_Simulation_with_Classic_GMC_IT", {
 })
 
 
-### Subordinator ###
+### TSS ###
 
-test_that("TemperedEstim_Simulation_with_Subordinator_GMM_IT",
+test_that("TemperedEstim_Simulation_with_TSS_GMM_IT",
   {
 
     TestObject <- TemperedEstim_Simulation(
       ParameterMatrix = rbind(c(0.5,1,1)), SampleSizes = 4, MCparam = 1,
-      TemperedType = "Subordinator", Estimfct = "GMM", saveOutput = FALSE,
+      TemperedType = "TSS", Estimfct = "GMM", saveOutput = FALSE,
       algo = "ITGMM", regularization = "cut-off", WeightingMatrix = "OptAsym",
       t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
 
@@ -238,12 +238,12 @@ test_that("TemperedEstim_Simulation_with_Subordinator_GMM_IT",
                                                    "lambdaE", "failure","time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Subordinator_GMM_Cue",
+test_that("TemperedEstim_Simulation_with_TSS_GMM_Cue",
     {
 
       TestObject <- TemperedEstim_Simulation(
         ParameterMatrix = rbind(c(0.5,1,1)), SampleSizes = 4, MCparam = 1,
-        TemperedType = "Subordinator", Estimfct = "GMM", saveOutput = FALSE,
+        TemperedType = "TSS", Estimfct = "GMM", saveOutput = FALSE,
         algo = "CueGMM", regularization = "cut-off", WeightingMatrix = "OptAsym",
         t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
 
@@ -257,11 +257,11 @@ test_that("TemperedEstim_Simulation_with_Subordinator_GMM_Cue",
 })
 
 
-test_that("TemperedEstim_Simulation_with_Subordinator_Cgmm_IT", {
+test_that("TemperedEstim_Simulation_with_TSS_Cgmm_IT", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(0.45,0.55,1)), SampleSizes = 2,
-    MCparam = 2, TemperedType = "Subordinator", Estimfct = "Cgmm",
+    MCparam = 2, TemperedType = "TSS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "ITCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -274,11 +274,11 @@ test_that("TemperedEstim_Simulation_with_Subordinator_Cgmm_IT", {
                                                  "lambdaE", "failure","time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Subordinator_Cgmm_Cue", {
+test_that("TemperedEstim_Simulation_with_TSS_Cgmm_Cue", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(0.45,0.55,1)), SampleSizes = 4,
-    MCparam = 1, TemperedType = "Subordinator", Estimfct = "Cgmm",
+    MCparam = 1, TemperedType = "TSS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "CueCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -293,13 +293,13 @@ test_that("TemperedEstim_Simulation_with_Subordinator_Cgmm_Cue", {
 })
 
 
-### Normal ###
+### NTS ###
 
-test_that("TemperedEstim_Simulation_with_Normal_GMM_IT", {
+test_that("TemperedEstim_Simulation_with_NTS_GMM_IT", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(0.5,1,1,1,1)), SampleSizes = 4, MCparam = 1,
-    TemperedType = "Normal", Estimfct = "GMM", saveOutput = FALSE,
+    TemperedType = "NTS", Estimfct = "GMM", saveOutput = FALSE,
     algo = "ITGMM", regularization = "cut-off", WeightingMatrix = "OptAsym",
     t_scheme = "free", alphaReg = 0.005, t_free = seq(0.1,2,length.out=12))
 
@@ -313,11 +313,11 @@ test_that("TemperedEstim_Simulation_with_Normal_GMM_IT", {
                                                  "time"))
 })
 
-test_that("TemperedEstim_Simulation_with_Normal_Cgmm_Cue", {
+test_that("TemperedEstim_Simulation_with_NTS_Cgmm_Cue", {
 
   TestObject <- TemperedEstim_Simulation(
     ParameterMatrix = rbind(c(0.55,0.55,1,1,1)), SampleSizes = 4,
-    MCparam = 1, TemperedType = "Normal", Estimfct = "Cgmm",
+    MCparam = 1, TemperedType = "NTS", Estimfct = "Cgmm",
     saveOutput = FALSE, algo = "CueCgmm", alphaReg = 0.01, subdivisions = 20,
     IntegrationMethod = "Uniform", randomIntegrationLaw = "unif", s_min = 0,
     s_max= 1)
@@ -335,10 +335,10 @@ test_that("TemperedEstim_Simulation_with_Normal_Cgmm_Cue", {
 
 ## GMC Tests ##
 
-test_that("TemperedEstim_Simulation_with_Subordinator_GMC_IT", {
+test_that("TemperedEstim_Simulation_with_TSS_GMC_IT", {
   TestObject <- TemperedEstim_Simulation(ParameterMatrix = rbind(c(0.5,1,1)),
                                          SampleSizes = c(2), MCparam = 2,
-                                         TemperedType = "Subordinator",
+                                         TemperedType = "TSS",
                                          Estimfct = "GMC",
                                          saveOutput = FALSE, algo = "ITGMC",
                                          alphaReg = 0.01,
@@ -348,11 +348,11 @@ test_that("TemperedEstim_Simulation_with_Subordinator_GMC_IT", {
   expect_equal(all(!is.na(TestObject)), TRUE)
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMC_IT", {
+test_that("TemperedEstim_Simulation_with_CTS_GMC_IT", {
   TestObject <- TemperedEstim_Simulation(ParameterMatrix =
                                            rbind(c(1.45,0.55,1,1,1,0)),
                                          SampleSizes = c(4), MCparam = 1,
-                                         TemperedType = "Classic",
+                                         TemperedType = "CTS",
                                          Estimfct = "GMC",
                                          saveOutput = FALSE, algo = "ITGMC",
                                          alphaReg = 0.01,
@@ -362,11 +362,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMC_IT", {
   expect_equal(all(!is.na(TestObject)), TRUE)
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMC_2S", {
+test_that("TemperedEstim_Simulation_with_CTS_GMC_2S", {
   TestObject <- TemperedEstim_Simulation(ParameterMatrix =
                                            rbind(c(1.45,0.55,1,1,1,0)),
                                          SampleSizes = c(2), MCparam = 1,
-                                         TemperedType = "Classic",
+                                         TemperedType = "CTS",
                                          Estimfct = "GMC",
                                          saveOutput = FALSE, algo = "2SGMC",
                                          alphaReg = 0.01,
@@ -376,11 +376,11 @@ test_that("TemperedEstim_Simulation_with_Classic_GMC_2S", {
   expect_equal(all(!is.na(TestObject)), TRUE)
 })
 
-test_that("TemperedEstim_Simulation_with_Classic_GMC_Cue", {
+test_that("TemperedEstim_Simulation_with_CTS_GMC_Cue", {
   TestObject <- TemperedEstim_Simulation(ParameterMatrix =
                                            rbind(c(1.45,0.55,1,1,1,0)),
                                          SampleSizes = c(4), MCparam = 1,
-                                         TemperedType = "Classic",
+                                         TemperedType = "CTS",
                                          Estimfct = "GMC",
                                          saveOutput = FALSE, algo = "CueGMC",
                                          alphaReg = 0.01,
